#pragma once

// To program Trinket 5V
// Board: Trinket Tiny @ 8MHz
// Programmer: USBtinyISP (vs AVRISP)  
// Getting "avrdude: error: usbtiny_receive:  (expected 4, got -5)" is normal?
// https://learn.adafruit.com/introducing-trinket/pinouts
// PIN0, GPIO, PWM, SDA <<<<<  BTN
// PIN1, GPIO, PWM, LED <<<<<< LED (or buzzer?)
// PIN2, GPIO, A/D#1, SDC <<<< LDR
// PIN3, USB!, A/D#3, 1.5kR P/U to 3.3V (N/A)
// PIN4, USB!, PWM, A/D#2 <<<< RELAY
//

//                          Schematic
//
//           (to "client")
//           +--USB OUT--+
//           |           |
//   +-------+-Gnd  5VDC-+----------------------------------+
//   |       +-----------+                                  |
//   |                                                      |
//   |                                                      |
//   |       +-Trinket 5V-+                   +--Relay--+   |
//   |       |            |                   |         |   |
//   |       x-BAT    USB-x           (RLY)---+-Signal  |   |
//   +-------+-Gnd   PIN0-+-(BTN)   +---------+-5VDC    |   |
//   | (RLY)-+-PIN4  PIN1-+-(LED)   |     +---+-Gnd     |   |
//   |       x-PIN3  PIN2-+-(LDR)   |     |   |     N/O-+---+
//   |       x-Rst   5VDC-+---------+     |   |     COM-+---+
//   |       +------------+         |     |   |     N/C-+   |
//   |                              |     |   +---------+   |
//   +------------------------------------+                 |  
//   |                              |                       |  
//   |                              |                       |  
//   |       +-----------+          |                       |  
//   +-------+-Gnd  5VDC-+----------+-----------------------+  
//           |           |
//           +--USB IN---+
//         (to power supply)
//
//
// (LED) is:
//   [PIN1]---[220R]---[LED]---[Gnd]
//
// (LDR) is:
//   +5V--[LDR]--+--[POT]--Gnd
//               |
//               |
//             [PIN2]
//
// (BTN) is:
//   [PIN0]---[Push button, N/O]---[Gnd]
//
// (RLY) is:
//   [PIN4]---[Relay Signal]
//
// Pins marked 'x' are unused
//


#ifdef ARDUINO_AVR_TRINKET3
#define PIN_BTN       0
#define PIN_LED       1
#define PIN_LDR_MODE  2
#define PIN_LDR_READ  1
#define PIN_RELAY     4
#else
// Prototyping on a Uno
#define PIN_RELAY     A0
#define PIN_LED       LED_BUILTIN
#define PIN_LDR_MODE  A5
#define PIN_LDR_READ  A5
#define PIN_BTN       4
#endif
